pub struct MandatePayload {
pub type: String,
pub user_agent: String,
pub user_ip: Option<String>,
}Expand description
Mandate is passed when a card is to be tokenized
Fields
type: StringIndicates the mandate type
user_agent: StringOperating system and web client used by the end-user
user_ip: Option<String>IP address of the end user. Supports IPv4 and IPv6