pub struct PaymentInstrumentResponse {
pub token: Option<String>,
pub active: Option<bool>,
pub type: Option<String>,
pub card: Option<PaymentInstrumentResponseCard>,
pub mandate: Option<MandateResponse>,
pub created_at: Option<DateTime>,
}Expand description
Payment Instrument Response
Fields
token: Option<String>Unique token identifying the saved payment card for a customer.
Constraints:
- read-only
active: Option<bool>Indicates whether the payment instrument is active and can be used for payments. To deactivate it, send a DELETE request to the resource endpoint.
Constraints:
- read-only
type: Option<String>Type of the payment instrument.
card: Option<PaymentInstrumentResponseCard>Details of the payment card.
mandate: Option<MandateResponse>created_at: Option<DateTime>Creation date of payment instrument. Response format expressed according to ISO8601 code.