pub struct MembershipUser {
pub id: String,
pub email: String,
pub mfa_on_login_enabled: bool,
pub virtual_user: bool,
pub service_account_user: bool,
pub disabled_at: Option<DateTime>,
pub nickname: Option<String>,
pub picture: Option<String>,
pub classic: Option<MembershipUserClassic>,
}Expand description
Information about the user associated with the membership.
Fields
id: StringIdentifier for the End-User (also called Subject).
email: StringEnd-User’s preferred e-mail address. Its value MUST conform to the RFC 5322 [RFC5322] addr-spec syntax. The RP MUST NOT rely upon this value being unique, for unique identification use ID instead.
mfa_on_login_enabled: boolTrue if the user has enabled MFA on login.
virtual_user: boolTrue if the user is a virtual user (operator).
service_account_user: boolTrue if the user is a service account.
disabled_at: Option<DateTime>Time when the user has been disabled. Applies only to virtual users (virtual_user: true).
nickname: Option<String>User’s preferred name. Used for display purposes only.
picture: Option<String>URL of the End-User’s profile picture. This URL refers to an image file (for example, a PNG, JPEG, or GIF image file), rather than to a Web page containing an image.
Constraints:
- format:
uri
classic: Option<MembershipUserClassic>Trait Implementations
Sourceimpl Clone for MembershipUser
impl Clone for MembershipUser
Sourcefn clone(&self) -> MembershipUser
fn clone(&self) -> MembershipUser
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more