ListParams

Struct ListParams 

pub struct ListParams {
    pub offset: Option<i64>,
    pub limit: Option<i64>,
    pub kind: Option<ResourceType>,
    pub status: Option<MembershipStatus>,
    pub resource_type: Option<ResourceType>,
    pub resource_attributes_sandbox: Option<bool>,
    pub resource_name: Option<String>,
    pub resource_parent_id: Option<Nullable<String>>,
    pub resource_parent_type: Option<Nullable<String>>,
    pub roles: Option<Vec<String>>,
}

Fields

offset: Option<i64>

Offset of the first member to return.

Constraints:

  • value >= 0
limit: Option<i64>

Maximum number of members to return.

Constraints:

  • value >= 1
  • value <= 25
kind: Option<ResourceType>

Filter memberships by resource kind.

status: Option<MembershipStatus>

Filter the returned memberships by the membership status.

resource_type: Option<ResourceType>

Filter memberships by resource kind.

resource_attributes_sandbox: Option<bool>

Filter memberships by the sandbox status of the resource the membership is in.

resource_name: Option<String>

Filter memberships by the name of the resource the membership is in.

resource_parent_id: Option<Nullable<String>>

Filter memberships by the parent of the resource the membership is in. When filtering by parent both resource.parent.id and resource.parent.type must be present. Pass explicit null to filter for resources without a parent.

resource_parent_type: Option<Nullable<String>>

Filter memberships by the parent of the resource the membership is in. When filtering by parent both resource.parent.id and resource.parent.type must be present. Pass explicit null to filter for resources without a parent.

roles: Option<Vec<String>>

Filter the returned memberships by role.