pub struct CheckoutTransactionsItem {Show 14 fields
pub id: Option<String>,
pub transaction_code: Option<String>,
pub amount: Option<f32>,
pub currency: Option<Currency>,
pub timestamp: Option<DateTime>,
pub status: Option<String>,
pub payment_type: Option<PaymentType>,
pub installments_count: Option<i64>,
pub merchant_code: Option<String>,
pub vat_amount: Option<f32>,
pub tip_amount: Option<f32>,
pub entry_mode: Option<EntryMode>,
pub auth_code: Option<String>,
pub internal_id: Option<i64>,
}Fields
id: Option<String>Unique ID of the transaction.
transaction_code: Option<String>Transaction code returned by the acquirer/processing entity after processing the transaction.
amount: Option<f32>Total amount of the transaction.
currency: Option<Currency>timestamp: Option<DateTime>Date and time of the creation of the transaction. Response format expressed according to ISO8601 code.
status: Option<String>Current status of the transaction.
payment_type: Option<PaymentType>installments_count: Option<i64>Current number of the installment for deferred payments.
Constraints:
- value >= 1
merchant_code: Option<String>Unique code of the registered merchant to whom the payment is made.
vat_amount: Option<f32>Amount of the applicable VAT (out of the total transaction amount).
tip_amount: Option<f32>Amount of the tip (out of the total transaction amount).
entry_mode: Option<EntryMode>auth_code: Option<String>Authorization code for the transaction sent by the payment card issuer or bank. Applicable only to card payments.
internal_id: Option<i64>Internal unique ID of the transaction on the SumUp platform.